Python: module boopak.testing

boopak.testing | index boopak/testing.py

`testing: Unit tests for Boodler.
To run all tests:
python -c 'from boopak import testing; testing.run()'
You can limit the test to a single module, or a space-separated list of
modules:
python -c 'from boopak import testing; testing.run("pinfo pload")'`

Modules
`` |  |
boodle booman | boopak sys | unittest |

Functions
`` |  | run(arglist=[])

Data
`` |  | testlist = [('version', <class 'boopak.test_version.TestVersion'>), ('sparse', <class 'boopak.test_sparse.TestSParse'>), ('argdef', <class 'boopak.test_argdef.TestArgDef'>), ('pinfo', <class 'boopak.test_pinfo.TestPInfo'>), ('pload', <class 'boopak.test_pload.TestPLoad'>), ('create', <class 'booman.create.TestCreate'>), ('stereo', <class 'boodle.stereo.TestStereo'>)]